@@ -1,9 +1,8 @@
 `kvCFA` <-
-function(n.i, X, tabdim, alpha=0.05)
+function(m.i, X, tabdim, alpha=0.05)
 #freq...vector of observedfrequencies
 #X...full design matrix (with intercept)
 {
-  m.i <- n.i
   fit <- FALSE
   strucmat <- diag(1,length(m.i))                          #starting matrix for removing cells
   i <- -1
@@ -26,7 +25,12 @@ function(n.i, X, tabdim, alpha=0.05)
     devVec <- cbind(devVec,result$deviance)
     pvalue <- 1-pchisq(result$deviance,chidf)                          #pvalue
     pvalueVec <- cbind(pvalueVec,pvalue)
-    rL <- list(paste("Step ",i),X,efreq,c(chisq,result$deviance,result$df.residual,pvalue))
+    fitvec <- c(chisq,result$deviance,result$df.residual,pvalue)
+    names(fitvec) <- c("LR","X^2","df","p") 
+    Xdes <- as.matrix(X)
+    colnames(Xdes) <- NULL
+    rownames(Xdes) <- NULL
+    rL <- list(desmat = Xdes, exp.freq = efreq, fitvec = fitvec)
     resList <- c(resList,rL)
 
     if (pvalue < alpha) {                                    #add structural coding vector
@@ -71,8 +75,21 @@ function(n.i, X, tabdim, alpha=0.05)
   strvec <- apply(namesmat,1,paste,collapse="")
   colnames(strucMat) <- strvec
   
-  result <- list(resstep = resList, dev.val = devVec, chisq.val = chisqVec,
-  df.val = chidfVec, p.val = pvalueVec, struc.mat = strucMat, typevec = typevec)
+  
+  restable <- data.frame(as.vector(devVec), as.vector(chisqVec), as.vector(chidfVec), as.vector(pvalueVec)) 
+  dimnames(restable)[[2]] <- c("LR","X^2","df","p")
+  dimnames(restable)[[1]] <- paste("Step",0:(dim(restable)[1]-1))
+  names(typevec) <- paste("Step",1:length(typevec))
+  
+  desmat <- resList[(length(resList)-2):length(resList)][[1]]               #design matrix
+  
+  lcomp <- unique(names(resList))
+  nsteps <- dim(restable)[1]
+  steplab <- paste("step", 1:5, sep = "")
+  names(resList) <- as.vector(t(outer(steplab, lcomp, paste, sep = "")))
+  
+  result <- list(restable = restable, design.mat = desmat,  struc.mat = strucMat, 
+                 typevec = typevec, resstep = resList)
 
   class(result) <- "kvCFA"
   result
